/***********************************************************************
 htsnp.h

 This code is part of the source to HapMotif package for analyzing
 conserved regions in haploid sequences of genetic variations.  See the
 README files for more information on the methods, use of the programs,
 and references.  This source code and any associated files are released
 under the terms of the MIT License, reproduced below.

 Copyright (c) 2003 Russell Schwartz, Department of Biological
 Sciences, Carnegie Mellon University.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
************************************************************************/

#ifndef HTSNPS_H
#define HTSNPS_H

double solutionCostPartial (string snps, int site, int offset, int maxLength,
			    vector<list<Motif> > &motifs,
			    map<Motif,double> &motifProbs);

bool incrementString (string &last);

list<string> extendString (string oldS, int extra);

int countX (string s);

double findBestInformativeSNPs (map<Motif,double> &motifProbs,
				list<int> &isnps, int maxSNPs);

double findAvgInformativeSNPs (map<Motif,double> &motifProbs, list<int> &isnps,
			       double avgError);

int findMaxInformativeSNPs (map<Motif,double> &motifProbs, list<int> &isnps,
			    double maxError);

void usage (char **argv);

void processCommandLine (int argc, char **argv, string &inputFile,
			 double &maxError, int &population,
			 double &confidence, int &maxSNPs, double &avgError);

#endif
